@@ -1,19 +1,8 @@
-/********************************************************************
-Copyright © 2019 Roman Gilg <subdiff@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2019 Roman Gilg <subdiff@gmail.com>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #pragma once
 
 #include "../common/control.h"
@@ -51,6 +40,11 @@ public:
         return m_initialConfig;
     }
 
+    void revertConfig()
+    {
+        m_config = m_previousConfig->clone();
+    }
+
     int retention() const;
     void setRetention(int retention);
 
@@ -71,9 +65,13 @@ public:
     KScreen::Output::VrrPolicy vrrPolicy(const KScreen::OutputPtr &output) const;
     void setVrrPolicy(const KScreen::OutputPtr &output, KScreen::Output::VrrPolicy value);
 
+    KScreen::Output::RgbRange rgbRange(const KScreen::OutputPtr &output) const;
+    void setRgbRange(const KScreen::OutputPtr &output, KScreen::Output::RgbRange value);
+
     void writeControl();
 
     void checkNeedsSave();
+    bool shouldTestNewSettings();
 
 Q_SIGNALS:
     void outputModelChanged();
@@ -91,9 +89,17 @@ private:
     void primaryOutputChanged(const KScreen::OutputPtr &output);
     void initOutput(const KScreen::OutputPtr &output);
     void resetScale(const KScreen::OutputPtr &output);
+    /**
+     * @brief checkSaveandTestCommon - compairs common config changes that would make the config dirty and needed to have the config checked when applied.
+     * @param isSaveCheck - True  if your checking to see if the changes should request a save.
+     *                      False if you want to check if you should test the config when applied.
+     * @return true, if you should check for a save or test the new configuration
+     */
+    bool checkSaveandTestCommon(bool isSaveCheck);
 
     KScreen::ConfigPtr m_config = nullptr;
     KScreen::ConfigPtr m_initialConfig;
+    KScreen::ConfigPtr m_previousConfig = nullptr;
     OutputModel *m_outputs = nullptr;
 
     std::unique_ptr<ControlConfig> m_control;
