@@ -1,19 +1,8 @@
-/********************************************************************
-Copyright © 2019 Roman Gilg <subdiff@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2019 Roman Gilg <subdiff@gmail.com>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "kcm.h"
 
 #include "../common/control.h"
@@ -100,6 +89,21 @@ void KCMKScreen::save()
     doSave(false);
 }
 
+void KCMKScreen::revertSettings()
+{
+    if (!m_config) {
+        setNeedsSave(false);
+        return;
+    }
+    if (!m_settingsReverted) {
+        m_config->revertConfig();
+        m_settingsReverted = true;
+        doSave(true);
+        load(); // reload the configuration
+        Q_EMIT settingsReverted();
+    }
+}
+
 void KCMKScreen::doSave(bool force)
 {
     if (!m_config) {
@@ -158,6 +162,12 @@ void KCMKScreen::doSave(bool force)
             return;
         }
         m_config->updateInitialData();
+
+        if (!m_settingsReverted && m_config->shouldTestNewSettings()) {
+            Q_EMIT showRevertWarning();
+        } else {
+            m_settingsReverted = false;
+        }
     });
 }
 
